import { lazy, useEffect, useState } from 'react'
import { supabase } from './supabaseClient'

const Auth = lazy(() => import('./Auth'))

async function addAthlete(e) {
  e.preventDefault()

  // Read the form data
  const formData = new FormData(e.target);
  const formJson = Object.fromEntries(formData.entries());

  if (defaultsSet(formJson)) {
    alert('Check data of the new athlete, seems like the defaults')
    return
  }

  // create new athlete
  const { error } = await supabase
    .from('athletes')
    .insert({
      nr: formJson.nr,
      firstname: formJson.firstname,
      lastname: formJson.lastname,
      birthday: formJson.birthday ? formJson.birthday : null,
      school: formJson.school
    })

  if (error === null) {
    window.location.reload()
  } else {
    alert('Failed to create new athlete: ' + error.message)
  }
}

function defaultsSet({nr, firstname, lastname, birthday, school}) {
  return (
    nr === '00'
    || firstname === 'Firstname *'
    || lastname === 'Lastname'
    || birthday === '0000-00-00'
    || school === 'School/team'
  )
}

async function deleteAthlete(e, athleteId, athleteFirstName, athleteLastName) {
  e.preventDefault()

  const athleteName = athleteFirstName + (athleteLastName ? ' ' + athleteLastName : '')
  if (window.confirm('Do you really want to delete athlete "' + athleteName + '"?')) {
    await supabase
      .from('athletes')
      .delete()
      .eq('id', athleteId)
    window.location.reload()
  }
}

function AthleteForm({session}) {
  const [loading, setLoading] = useState(false)
  const [athletes, setAthletes] = useState([])

  useEffect(() => {
    (async () => {
      setLoading(true)
      const athleteList = await supabase.from('athletes').select()
      if (athleteList.error === null)
        setAthletes(athleteList.data)
      setLoading(false)
    })();
  }, [])

  return (
    <div>
      <button disabled={!loading}>{loading ? '🔄 loading' : ''}</button>
      <form method='post' onSubmit={addAthlete}>
        <table>
          <thead>
            <tr>
              <th>Created at</th>
              <th>Start Nr.</th>
              <th>Firstname</th>
              <th>Lastname</th>
              <th>Birthday</th>
              <th>School</th>
              <th>New/delete</th>
            </tr>
          </thead>
          <tbody>
            {athletes.map(a => (
              <tr key={a.id}>
                <td data-title='Created at' className='right'>{new Date(a.created_at).toLocaleString()}</td>
                <td data-title='Start Nr.' className='right'>{a.nr}</td>
                <td data-title='Firstname'>{a.firstname}</td>
                <td data-title='Lastname'>{a.lastname}</td>
                <td data-title='Birthday'>{a.birthday}</td>
                <td data-title='School'>{a.school}</td>
                <td><button onClick={e => deleteAthlete(e, a.id, a.firstname, a.lastname)}>🗑️ delete</button></td>
              </tr>
            ))}
            <tr>
              <td className='right'><i>* required</i></td>
              <td data-title='Start Nr. *' className='right'>
                <input type='number' name='nr' defaultValue='00' />
              </td>
              <td data-title='Firstname *'>
                <input type='text' name='firstname' defaultValue='Firstname *' />
              </td>
              <td data-title='Lastname'>
                <input type='text' name='lastname' defaultValue='Lastname' />
              </td>
              <td data-title='Birthday' className='right'>
                <input
                  type='date'
                  name='birthday' />
              </td>
              <td data-title='School'>
                <input type='text' name='school' defaultValue='School/team' />
              </td>
              <td>
                <button type='submit'>➕ new</button>
              </td>
            </tr>
          </tbody>
        </table>
      </form>
    </div>
  )
}

function Athletes({session}) {
    return (
      <div>
        {!session ? <Auth /> : <AthleteForm session={session} />}
      </div>
    )
  }
  
export default Athletes
