import { lazy, useEffect, useState } from 'react'
import { useParams } from 'react-router-dom'
import Select from 'react-select'
import { supabase } from './supabaseClient'

const Auth = lazy(() => import('./Auth'))

async function addAthleteToHeat(e, selectedAthlete, heatId) {
  e.preventDefault()

  const { error } = await supabase.from('startlist').upsert({
    athlete: selectedAthlete.value,
    heat: heatId
  })

  if (error === null)
    window.location.reload()
}

async function removeAthleteFromHeat(e, startlistId, athleteFirstName, athleteLastName, heatName) {
  e.preventDefault()
  const athleteName = athleteFirstName + (athleteLastName ? ' ' + athleteLastName : '')

  if (window.confirm('Do you really want to remove athlete "' + athleteName + '" from heat "' + heatName + '"?')) {
    await supabase
      .from('startlist')
      .delete()
      .eq('id', startlistId)
    window.location.reload()
  }
}

function StartlistForm({heatId}) {
  const [heatName, setheatName] = useState("")
  const [heatLocation, setheatLocation] = useState("")
  const [heatStart, setheatStart] = useState("")
  const [startlist, setStartlist] = useState([])
  const [athleteOpts, setAthleteOpts] = useState([])
  const [selectedAthlete, setselectedAthlete] = useState({})

  const [loading, setLoading] = useState(false)

  useEffect(() => {
    (async () => {
      setLoading(true)

      const startlistData = await supabase
        .from('startlist')
        .select(`
          id,
          heat,
          athlete (
            id,
            nr,
            firstname,
            lastname,
            birthday,
            school
          )
        `)
      .eq('heat', heatId)

      if (startlistData.error === null)
        setStartlist(startlistData.data)

      const heatData = await supabase
        .from('heats')
        .select('name, location, planned_start')
        .eq('id', heatId)
        .single()

      if (heatData.error === null) {
        setheatName(heatData.data.name)
        setheatLocation(heatData.data.location)
        setheatStart(heatData.data.planned_start)
      }

      const athleteList = await supabase.from('athletes').select()
      if (athleteList.error === null) {
        let options = athleteList.data.map(a => {
          return {
            value: a.id,
            label: a.nr + " " + a.firstname + " " + (a.lastname ? a.lastname : "")
          }
        })
        setAthleteOpts(options)
      }

      setLoading(false)
    })();
  }, [heatId])

  return (
    <div>
      <button disabled={!loading}>{loading ? '🔄 loading' : ''}</button>
      <h1>Startlist #{heatId} {heatName}</h1>
      <div className='heatInfo'>
        <ul>
          <li><b>Location:</b> {heatLocation ? heatLocation : 'n/a'}</li>
          <li><b>Planned start:</b> {heatStart ? heatStart : 'n/a'}</li>
        </ul>
      </div>
      <table>
        <thead>
          <tr>
            <th>Start Nr.</th>
            <th>Firstname</th>
            <th>Lastname</th>
            <th>Birthday</th>
            <th>School</th>
            <th>Add/remove</th>
          </tr>
        </thead>
        <tbody>
        {startlist.map(i => (
            <tr key={i.id}>
              <td data-title='Start Nr.' className='right'>{i.athlete.nr}</td>
              <td data-title='Firstname'>{i.athlete.firstname}</td>
              <td data-title='Lastname'>{i.athlete.lastname}</td>
              <td data-title='Birthday'>{i.athlete.birthday}</td>
              <td data-title='School'>{i.athlete.school}</td>
              <td><button onClick={e => removeAthleteFromHeat(
                e,
                i.id,
                i.athlete.firstname,
                i.athlete.lastname,
                heatName
              )}>🗑️ remove</button></td>
            </tr>
          ))}
          <tr>
            <td data-title='Athlete' colSpan={5}>
              <Select
                options={athleteOpts}
                onChange={(e) => setselectedAthlete(e)}
              />
            </td>
            <td>
              <button onClick={(e) => addAthleteToHeat(e, selectedAthlete, heatId)}>➕ add</button>
            </td>
          </tr>
        </tbody>
      </table>
    </div>
  )
}

function Startlist({session}) {
    const { heatId } = useParams();

    return (
      <div>
        {!session ? <Auth /> : <StartlistForm heatId={heatId} />}
      </div>
    )
  }
  
export default Startlist
